.icon[data-v-e18d7eb2]{font-size:1rem;margin-right:.5rem}.menu hr[data-v-e18d7eb2]{margin-bottom:1rem}.menu .container[data-v-e18d7eb2]{background-color:var(--secondary-background-color);border-radius:.5rem}.menu-title[data-v-e18d7eb2],.menu .nav-item .nav-link.active[data-v-e18d7eb2],.menu .nav-link[data-v-e18d7eb2],hr[data-v-e18d7eb2]{color:var(--text-color)}.menu .nav-link[data-v-e18d7eb2]{margin-bottom:.5rem;padding-top:.5rem;padding-bottom:.5rem}.menu .nav-item .nav-link.active[data-v-e18d7eb2]{background-color:var(--primary-color)}.nav-link.active+.icon[data-v-e18d7eb2],.nav-link.active[data-v-e18d7eb2]{font-weight:900}.err__msg[data-v-bef81972],.err__title[data-v-bef81972]{margin:0}body{margin:0}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}