(function(e){function t(t){for(var r,o,i=t[0],u=t[1],l=t[2],b=0,d=[];b<i.length;b++)o=i[b],Object.prototype.hasOwnProperty.call(c,o)&&c[o]&&d.push(c[o][0]),c[o]=0;for(r in u)Object.prototype.hasOwnProperty.call(u,r)&&(e[r]=u[r]);s&&s(t);while(d.length)d.shift()();return a.push.apply(a,l||[]),n()}function n(){for(var e,t=0;t<a.length;t++){for(var n=a[t],r=!0,i=1;i<n.length;i++){var u=n[i];0!==c[u]&&(r=!1)}r&&(a.splice(t--,1),e=o(o.s=n[0]))}return e}var r={},c={app:0},a=[];function o(t){if(r[t])return r[t].exports;var n=r[t]={i:t,l:!1,exports:{}};return e[t].call(n.exports,n,n.exports,o),n.l=!0,n.exports}o.m=e,o.c=r,o.d=function(e,t,n){o.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:n})},o.r=function(e){"undefined"!==typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},o.t=function(e,t){if(1&t&&(e=o(e)),8&t)return e;if(4&t&&"object"===typeof e&&e&&e.__esModule)return e;var n=Object.create(null);if(o.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)o.d(n,r,function(t){return e[t]}.bind(null,r));return n},o.n=function(e){var t=e&&e.__esModule?function(){return e["default"]}:function(){return e};return o.d(t,"a",t),t},o.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},o.p="";var i=window["webpackJsonp"]=window["webpackJsonp"]||[],u=i.push.bind(i);i.push=t,i=i.slice();for(var l=0;l<i.length;l++)t(i[l]);var s=u;a.push([0,"chunk-vendors"]),n()})({0:function(e,t,n){e.exports=n("cd49")},"04d9":function(e,t,n){"use strict";n("b4b3")},"1eca":function(e,t,n){},"44dc":function(e,t,n){"use strict";n("1eca")},8966:function(e,t,n){"use strict";n("9c84")},"9c84":function(e,t,n){},b4b3:function(e,t,n){},cd49:function(e,t,n){"use strict";n.r(t);n("e260"),n("e6cf"),n("cca6"),n("a79d");var r=n("830f"),c=n("5c40"),a={id:"app"};function o(e,t,n,r,o,i){var u=Object(c["w"])("MyComponent"),l=Object(c["w"])("WithStreamlitConnection");return Object(c["r"])(),Object(c["d"])("div",a,[Object(c["i"])(l,null,{default:Object(c["C"])((function(e){var t=e.args;return[Object(c["i"])(u,{args:t},null,8,["args"])]})),_:1})])}var i=n("9ff4"),u=Object(c["D"])("data-v-e18d7eb2");Object(c["t"])("data-v-e18d7eb2");var l={class:"menu"},s={class:"container d-flex flex-column flex-shrink-0 p-3"},b={href:"#",class:"menu-title align-items-center mb-md-0 me-md-auto text-decoration-none"},d={class:"fs-4"},f=Object(c["i"])("hr",null,null,-1),j={href:"#",class:"nav nav-pills flex-column mb-auto"},O={key:0};Object(c["s"])();var v=u((function(e,t,n,r,a,o){return Object(c["r"])(),Object(c["d"])("div",l,[Object(c["i"])("div",s,[Object(c["i"])("a",b,[Object(c["i"])("i",{class:["icon",e.menuIcon],style:{"font-size":"3rem"}},null,2),Object(c["i"])("span",d,Object(i["F"])(e.menuTitle),1)]),f,Object(c["i"])("ul",j,[(Object(c["r"])(!0),Object(c["d"])(c["b"],null,Object(c["u"])(e.args.options,(function(t,n){return Object(c["r"])(),Object(c["d"])("li",{class:"nav-item",key:t},["---"===t?(Object(c["r"])(),Object(c["d"])("hr",O)):(Object(c["r"])(),Object(c["d"])("a",{key:1,href:"#",class:["nav-link",{active:n==e.selectedIndex}],onClick:function(r){return e.onClicked(n,t)},"aria-current":"page"},[Object(c["i"])("i",{class:["icon",e.icons[n]]},null,2),Object(c["h"])(" "+Object(i["F"])(t),1)],10,["onClick"]))])})),128))])])])})),p=(n("fb6a"),n("a1e9")),m=n("d092");function g(){Object(c["o"])((function(){m["a"].setFrameHeight()})),Object(c["q"])((function(){m["a"].setFrameHeight()}))}
/**
 * @license
 * Copyright 2018-2020 Streamlit Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */n("ab8b"),n("cd74");function h(e){return"bi-"!==e.slice(0,3)?"bi-"+e:e}var y={name:"MyComponent",props:["args"],setup:function(e){g();var t=Object(p["i"])(e.args.menuTitle||"Menu"),n=Object(p["i"])(e.args.menuIcon||"bi-menu-up");n.value=h(n.value);for(var r=Object(p["i"])(e.args.icons||[]),c=0;c<e.args.options.length;c++)r.value[c]||(r.value[c]="bi-caret-right"),r.value[c]=h(r.value[c]);var a=Object(p["i"])(e.args.defaultIndex),o=function(e,t){a.value=e,m["a"].setComponentValue(t)};return{selectedIndex:a,menuTitle:t,menuIcon:n,icons:r,onClicked:o}}};n("8966");y.render=v,y.__scopeId="data-v-e18d7eb2";var _=y,k=Object(c["D"])("data-v-bef81972");Object(c["t"])("data-v-bef81972");var x={key:0},C=Object(c["i"])("h1",{class:"err__title"},"Component Error",-1),E={class:"err__msg"};Object(c["s"])();var w=k((function(e,t,n,r,a,o){return Object(c["r"])(),Object(c["d"])("div",null,[""!=e.componentError?(Object(c["r"])(),Object(c["d"])("div",x,[C,Object(c["i"])("div",E,"Message: "+Object(i["F"])(e.componentError),1)])):null!=e.renderData?Object(c["v"])(e.$slots,"default",{key:1,args:e.renderData.args,disabled:e.renderData.disabled}):Object(c["e"])("",!0)])})),M=Object(c["j"])({name:"WithStreamlitConnection",setup:function(){var e=Object(p["i"])(void 0),t=Object(p["i"])(""),n=function(n){var r=n;e.value=r.detail,t.value=""};return Object(c["o"])((function(){m["a"].events.addEventListener(m["a"].RENDER_EVENT,n),m["a"].setComponentReady()})),Object(c["q"])((function(){""!=t.value&&m["a"].setFrameHeight()})),Object(c["p"])((function(){m["a"].events.removeEventListener(m["a"].RENDER_EVENT,n)})),Object(c["n"])((function(e){t.value=String(e)})),{renderData:e,componentError:t}}});n("44dc");M.render=w,M.__scopeId="data-v-bef81972";var S=M,D=Object(c["j"])({name:"App",components:{MyComponent:_,WithStreamlitConnection:S}});n("04d9");D.render=o;var I=D;Object(r["a"])(I).mount("#app")}});
//# sourceMappingURL=app.9f1cf9f4.js.map